# Imbalanced-LightGBM

  <a href="https://github.com/RektPunk/Imbalance-LightGBM/blob/main/LICENSE">
    <img alt="License" src="https://img.shields.io/github/license/RektPunk/Imbalance-LightGBM.svg">
  </a>
  <a href="https://github.com/RektPunk/Imbalance-LightGBM/actions/workflows/lint.yaml">
    <img alt="Lint" src="https://github.com/RektPunk/Imbalance-LightGBM/actions/workflows/lint.yaml/badge.svg?branch=main">
  </a>

This repository contains implementations of weighted loss and focal loss functions specifically designed for classification problems using LightGBM.

## Installation
Not implemented yet.


## Example
Please refer to the [**Examples**](https://github.com/RektPunk/Imbalance-LightGBM/tree/main/examples) provided for further clarification.


## Acknowledgements
This repository would not exist without the excellent work from:

- [LightGBM](https://github.com/microsoft/LightGBM)
- [Imbalance-XGBoost](https://github.com/jhwjhw0123/Imbalance-XGBoost)
